"use strict";

var _interopRequireWildcard = require("@babel/runtime/helpers/interopRequireWildcard").default;
var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault").default;
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.NavigationImpl = exports.Navigation = void 0;
exports.useNavigation = useNavigation;
var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));
var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));
var _react = _interopRequireWildcard(require("react"));
var _styled = _interopRequireDefault(require("@emotion/styled"));
var _Drawer = require("@webiny/ui/Drawer");
var _appAdmin = require("@webiny/app-admin");
var _Hamburger = _interopRequireDefault(require("./Hamburger"));
var _MenuGroupRenderer = require("./renderers/MenuGroupRenderer");
var _MenuSectionItemRenderer = require("./renderers/MenuSectionItemRenderer");
var _MenuSectionRenderer = require("./renderers/MenuSectionRenderer");
var _MenuLinkRenderer = require("./renderers/MenuLinkRenderer");
var _MenuElementRenderer = require("./renderers/MenuElementRenderer");
var _List = require("@webiny/ui/List");
var _Styled = require("./Styled");
var _config = require("@webiny/app/config");
var _Typography = require("@webiny/ui/Typography");
var AutoWidthDrawer = /*#__PURE__*/(0, _styled.default)(_Drawer.Drawer, {
  label: "AutoWidthDrawer",
  target: "e17n5u7b0"
})("width:auto;");
var NavigationContext = /*#__PURE__*/_react.default.createContext({
  visible: false,
  setVisible: function setVisible() {
    return void 0;
  }
});
NavigationContext.displayName = "NavigationContext";
function useNavigation() {
  return (0, _react.useContext)(NavigationContext);
}
var BrandImpl = function BrandImpl(Brand) {
  return function BrandWithHamburger() {
    return /*#__PURE__*/_react.default.createElement(_react.Fragment, null, /*#__PURE__*/_react.default.createElement(_Hamburger.default, null), /*#__PURE__*/_react.default.createElement(Brand, null));
  };
};
var NavigationProvider = function NavigationProvider(Component) {
  return function NavigationProvider(props) {
    var _useState = (0, _react.useState)(false),
      _useState2 = (0, _slicedToArray2.default)(_useState, 2),
      visible = _useState2[0],
      setVisible = _useState2[1];
    var context = (0, _react.useMemo)(function () {
      return {
        visible: visible,
        setVisible: setVisible
      };
    }, [visible]);
    return /*#__PURE__*/_react.default.createElement(NavigationContext.Provider, {
      value: context
    }, /*#__PURE__*/_react.default.createElement(Component, props));
  };
};
var NavigationImpl = function NavigationImpl() {
  return function Navigation() {
    var _useAdminNavigation = (0, _appAdmin.useNavigation)(),
      menuItems = _useAdminNavigation.menuItems;
    var _useNavigation = useNavigation(),
      visible = _useNavigation.visible,
      setVisible = _useNavigation.setVisible;
    var hideDrawer = (0, _react.useCallback)(function () {
      setVisible(false);
    }, []);
    var mainMenu = (0, _react.useMemo)(function () {
      return menuItems.filter(function (m) {
        return !(m.tags || []).includes("footer");
      });
    }, [menuItems]);
    var footerMenu = (0, _react.useMemo)(function () {
      return menuItems.filter(function (m) {
        return (m.tags || []).includes("footer");
      });
    }, [menuItems]);
    var wbyVersion = _config.config.getKey("WEBINY_VERSION", process.env.REACT_APP_WEBINY_VERSION);
    return /*#__PURE__*/_react.default.createElement(AutoWidthDrawer, {
      modal: true,
      open: visible,
      onClose: hideDrawer
    }, /*#__PURE__*/_react.default.createElement(_Drawer.DrawerHeader, {
      className: _Styled.navHeader
    }, /*#__PURE__*/_react.default.createElement(_Styled.MenuHeader, null, /*#__PURE__*/_react.default.createElement(_appAdmin.Brand, null))), /*#__PURE__*/_react.default.createElement(_Drawer.DrawerContent, {
      className: _Styled.navContent
    }, /*#__PURE__*/_react.default.createElement(_appAdmin.MenuItems, {
      menuItems: mainMenu
    })), /*#__PURE__*/_react.default.createElement(_Styled.MenuFooter, null, /*#__PURE__*/_react.default.createElement(_List.List, {
      nonInteractive: true
    }, /*#__PURE__*/_react.default.createElement(_appAdmin.MenuItems, {
      menuItems: footerMenu
    }), /*#__PURE__*/_react.default.createElement(_List.ListItem, {
      ripple: false,
      className: _Styled.subFooter
    }, /*#__PURE__*/_react.default.createElement(_Typography.Typography, {
      use: "body2"
    }, "Webiny v", wbyVersion)))));
  };
};
exports.NavigationImpl = NavigationImpl;
var menuSorter = function menuSorter(a, b) {
  if (a.pin === b.pin) {
    return (a.label || "").localeCompare(b.label || "");
  }
  if (a.pin) {
    return a.pin === "first" ? -1 : 1;
  }
  if (b.pin) {
    return b.pin === "first" ? 1 : -1;
  }
  return (a.label || "").localeCompare(b.label || "");
};
var SortedMenuItems = function SortedMenuItems(MenuItems) {
  return function SortedMenuItems(_ref) {
    var menuItems = _ref.menuItems;
    return /*#__PURE__*/_react.default.createElement(MenuItems, {
      menuItems: (0, _toConsumableArray2.default)(menuItems).sort(menuSorter)
    });
  };
};
var Navigation = function Navigation() {
  return /*#__PURE__*/_react.default.createElement(_react.Fragment, null, /*#__PURE__*/_react.default.createElement(_appAdmin.Provider, {
    hoc: NavigationProvider
  }), /*#__PURE__*/_react.default.createElement(_appAdmin.Compose, {
    component: _appAdmin.NavigationRenderer,
    with: NavigationImpl
  }), /*#__PURE__*/_react.default.createElement(_appAdmin.Compose, {
    component: _appAdmin.MenuItems,
    with: SortedMenuItems
  }), /*#__PURE__*/_react.default.createElement(_appAdmin.Compose, {
    component: _appAdmin.Brand,
    with: BrandImpl
  }), /*#__PURE__*/_react.default.createElement(_appAdmin.Compose, {
    component: _appAdmin.MenuItemRenderer,
    with: [_MenuGroupRenderer.MenuGroupRenderer, _MenuSectionItemRenderer.MenuSectionItemRenderer, _MenuSectionRenderer.MenuSectionRenderer, _MenuLinkRenderer.MenuLinkRenderer, _MenuElementRenderer.MenuElementRenderer]
  }));
};
exports.Navigation = Navigation;

//# sourceMappingURL=index.js.map